@@ -5,12 +5,12 @@ use warnings;
 
 use Carp;
 use Clone::Choose 0.008;
-use Scalar::Util qw(blessed);
+use Scalar::Util qw(blessed weaken);
 
 use base 'Exporter';
 our $CONTEXT;
 
-our $VERSION     = '0.300';
+our $VERSION     = '0.301';
 our @EXPORT_OK   = qw( merge _hashify _merge_hashes );
 our %EXPORT_TAGS = ('custom' => [qw( _hashify _merge_hashes )]);
 
@@ -18,6 +18,9 @@ sub _init
 {
     my $self = shift;
 
+    my $weak = $self;
+    weaken $weak;
+
     defined $self->{behaviors}
       or $self->{behaviors} = {
         'LEFT_PRECEDENT' => {
@@ -34,7 +37,7 @@ sub _init
             'HASH' => {
                 'SCALAR' => sub { $_[0] },
                 'ARRAY'  => sub { $_[0] },
-                'HASH'   => sub { $self->_merge_hashes($_[0], $_[1]) },
+                'HASH'   => sub { $weak->_merge_hashes($_[0], $_[1]) },
             },
         },
 
@@ -52,7 +55,7 @@ sub _init
             'HASH' => {
                 'SCALAR' => sub { $_[1] },
                 'ARRAY'  => sub { [values %{$_[0]}, @{$_[1]}] },
-                'HASH'   => sub { $self->_merge_hashes($_[0], $_[1]) },
+                'HASH'   => sub { $weak->_merge_hashes($_[0], $_[1]) },
             },
         },
 
@@ -70,25 +73,25 @@ sub _init
             'HASH' => {
                 'SCALAR' => sub { $_[0] },
                 'ARRAY'  => sub { $_[0] },
-                'HASH'   => sub { $self->_merge_hashes($_[0], $_[1]) },
+                'HASH'   => sub { $weak->_merge_hashes($_[0], $_[1]) },
             },
         },
 
         'RETAINMENT_PRECEDENT' => {
             'SCALAR' => {
-                'SCALAR' => sub { [$_[0],                                      $_[1]] },
-                'ARRAY'  => sub { [$_[0],                                      @{$_[1]}] },
-                'HASH'   => sub { $self->_merge_hashes($self->_hashify($_[0]), $_[1]) },
+                'SCALAR' => sub { [$_[0], $_[1]] },
+                'ARRAY'  => sub { [$_[0], @{$_[1]}] },
+                'HASH'   => sub { $weak->_merge_hashes($weak->_hashify($_[0]), $_[1]) },
             },
             'ARRAY' => {
-                'SCALAR' => sub { [@{$_[0]},                                   $_[1]] },
-                'ARRAY'  => sub { [@{$_[0]},                                   @{$_[1]}] },
-                'HASH'   => sub { $self->_merge_hashes($self->_hashify($_[0]), $_[1]) },
+                'SCALAR' => sub { [@{$_[0]}, $_[1]] },
+                'ARRAY'  => sub { [@{$_[0]}, @{$_[1]}] },
+                'HASH'   => sub { $weak->_merge_hashes($weak->_hashify($_[0]), $_[1]) },
             },
             'HASH' => {
-                'SCALAR' => sub { $self->_merge_hashes($_[0], $self->_hashify($_[1])) },
-                'ARRAY'  => sub { $self->_merge_hashes($_[0], $self->_hashify($_[1])) },
-                'HASH'   => sub { $self->_merge_hashes($_[0], $_[1]) },
+                'SCALAR' => sub { $weak->_merge_hashes($_[0], $weak->_hashify($_[1])) },
+                'ARRAY'  => sub { $weak->_merge_hashes($_[0], $weak->_hashify($_[1])) },
+                'HASH'   => sub { $weak->_merge_hashes($_[0], $_[1]) },
             },
         },
       };
@@ -118,7 +121,7 @@ sub set_behavior
     my $self  = &_get_obj;    # '&' + no args modifies current @_
     my $value = shift;
 
-    my @behaviors = grep { /$value/i } keys %{$self->{'behaviors'}};
+    my @behaviors = grep { /^$value$/i } keys %{$self->{'behaviors'}};
     if (scalar @behaviors == 0)
     {
         carp 'Behavior must be one of : ' . join(', ', keys %{$self->{'behaviors'}});
@@ -563,8 +566,8 @@ Stefan Hermes E<lt>hermes@cpan.orgE<gt>
 =head1 COPYRIGHT
 
 Copyright (c) 2001,2002 Michael K. Neylon. All rights reserved.
-Copyright (c) 2013-2017 Jens Rehsack. All rights reserved.
-Copyright (c) 2017 Stefan Hermes. All rights reserved.
+Copyright (c) 2013-2020 Jens Rehsack. All rights reserved.
+Copyright (c) 2017-2020 Stefan Hermes. All rights reserved.
 
 This library is free software.  You can redistribute it and/or modify it 
 under the same terms as Perl itself.
